# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # JOB - Superuser
    def v1_superuser_cron_job_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:job-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp


class RemoteTestMixin:
    # JOB LOG - Superuser
    def v1_superuser_cron_job_log_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:joblog-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_log_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:joblog-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_log_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:joblog-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_cron_job_log_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-cron:joblog-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

