# -*- coding: utf-8 -*-

from rest_framework import exceptions, viewsets
from rest_framework.decorators import action

from web.api.views import ThuxViewMixin
from . import serializers
from ... import models


# JOB
class JobViewSet(ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Job.objects.all()
    serializer_class = serializers.JobSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Job{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)


# JOB LOG
class JobLogViewSet(ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.JobLog.objects.all()
    serializer_class = serializers.JobLogSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'JobLog{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)